==> feincms3-0.25.1.tar.gz: feincms3-0.25.1/setup.py <==
#!/usr/bin/env python

import os
from io import open

from setuptools import find_packages, setup


def read(filename):
    path = os.path.join(os.path.dirname(__file__), filename)
    with open(path, encoding='utf-8') as handle:
        return handle.read()


setup(
    name='feincms3',
    version=__import__('feincms3').__version__,
    description='CMS-building toolkit for Django',
    long_description=read('README.rst'),
    author='Matthias Kestenholz',
    author_email='mk@feinheit.ch',
    url='https://github.com/matthiask/feincms3/',
    license='BSD License',
    platforms=['OS Independent'],
    packages=find_packages(
        exclude=['tests', 'testapp']
    ),
    include_package_data=True,
    install_requires=[
        'django-content-editor',
        'django-tree-queries',
    ],
    extras_require={
        'all': [
            'django-ckeditor',
            'django-imagefield',
            'html-sanitizer>=1.1.1',
            'requests',
        ],
        'versatileimagefield': [
            'django-ckeditor',
            'django-versatileimagefield',
            'html-sanitizer>=1.1.1',
            'requests',
        ],
    },
    classifiers=[
        # 'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development',
        'Topic :: Software Development :: Libraries :: Application Frameworks',
    ],
    zip_safe=False,
)

==> feincms3-0.26.2.tar.gz: feincms3-0.26.2/setup.py <==
#!/usr/bin/env python

import os
from io import open

from setuptools import find_packages, setup


def read(filename):
    path = os.path.join(os.path.dirname(__file__), filename)
    with open(path, encoding='utf-8') as handle:
        return handle.read()


setup(
    name='feincms3',
    version=__import__('feincms3').__version__,
    description='CMS-building toolkit for Django',
    long_description=read('README.rst'),
    author='Matthias Kestenholz',
    author_email='mk@feinheit.ch',
    url='https://github.com/matthiask/feincms3/',
    license='BSD License',
    platforms=['OS Independent'],
    packages=find_packages(
        exclude=['tests', 'testapp']
    ),
    include_package_data=True,
    install_requires=[
        'django-content-editor',
        'django-tree-queries>0.2',
    ],
    extras_require={
        'all': [
            'django-ckeditor',
            'django-imagefield',
            'html-sanitizer>=1.1.1',
            'requests',
        ],
        'versatileimagefield': [
            'django-ckeditor',
            'django-versatileimagefield',
            'html-sanitizer>=1.1.1',
            'requests',
        ],
    },
    classifiers=[
        # 'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development',
        'Topic :: Software Development :: Libraries :: Application Frameworks',
    ],
    zip_safe=False,
)
